@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Tools for mocking parts of PyMongo to test other parts."""
+from __future__ import annotations
 
 import contextlib
 import weakref
@@ -38,7 +39,7 @@ class MockPool(Pool):
         Pool.__init__(self, (client_context.host, client_context.port), *args, **kwargs)
 
     @contextlib.contextmanager
-    def get_socket(self, handler=None):
+    def checkout(self, handler=None):
         client = self.client
         host_and_port = f"{self.mock_host}:{self.mock_port}"
         if host_and_port in client.mock_down_hosts:
@@ -48,10 +49,10 @@ class MockPool(Pool):
             client.mock_standalones + client.mock_members + client.mock_mongoses
         ), ("bad host: %s" % host_and_port)
 
-        with Pool.get_socket(self, handler) as sock_info:
-            sock_info.mock_host = self.mock_host
-            sock_info.mock_port = self.mock_port
-            yield sock_info
+        with Pool.checkout(self, handler) as conn:
+            conn.mock_host = self.mock_host
+            conn.mock_port = self.mock_port
+            yield conn
 
 
 class DummyMonitor:
@@ -85,7 +86,7 @@ class MockMonitor(Monitor):
     def _check_once(self):
         client = self.client
         address = self._server_description.address
-        response, rtt = client.mock_hello("%s:%d" % address)
+        response, rtt = client.mock_hello("%s:%d" % address)  # type: ignore[str-format]
         return ServerDescription(address, Hello(response), rtt)
 
 
