@@ -14,6 +14,7 @@
 # limitations under the License.
 
 """Test the bson module."""
+from __future__ import annotations
 
 import array
 import collections
@@ -50,6 +51,7 @@ from bson import (
 from bson.binary import Binary, UuidRepresentation
 from bson.code import Code
 from bson.codec_options import CodecOptions, DatetimeConversion
+from bson.datetime_ms import _DATETIME_ERROR_SUGGESTION
 from bson.dbref import DBRef
 from bson.errors import InvalidBSON, InvalidDocument
 from bson.int64 import Int64
@@ -121,7 +123,6 @@ class TestBSON(unittest.TestCase):
         self.assertRaises(InvalidBSON, decode, data)
 
     def check_encode_then_decode(self, doc_class=dict, decoder=decode, encoder=encode):
-
         # Work around http://bugs.jython.org/issue1728
         if sys.platform.startswith("java"):
             doc_class = SON
@@ -529,8 +530,8 @@ class TestBSON(unittest.TestCase):
     def test_bytes_as_keys(self):
         doc = {b"foo": "bar"}
         # Since `bytes` are stored as Binary you can't use them
-        # as keys in python 3.x. Using binary data as a key makes
-        # no sense in BSON anyway and little sense in python.
+        # as keys. Using binary data as a key makes no sense in BSON
+        # anyway and little sense in python.
         self.assertRaises(InvalidDocument, encode, doc)
 
     def test_datetime_encode_decode(self):
@@ -1309,6 +1310,11 @@ class TestDatetimeConversion(unittest.TestCase):
         with self.assertRaises(TypeError):
             encode({"x": float_ms})
 
+        # Test InvalidBSON errors on conversion include _DATETIME_ERROR_SUGGESTION
+        small_ms = -2 << 51
+        with self.assertRaisesRegex(InvalidBSON, re.compile(re.escape(_DATETIME_ERROR_SUGGESTION))):
+            decode(encode({"a": DatetimeMS(small_ms)}))
+
 
 class TestLongLongToString(unittest.TestCase):
     def test_long_long_to_string(self):
