@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test the Transactions unified spec tests."""
+from __future__ import annotations
 
 import os
 import sys
@@ -23,8 +24,7 @@ from test import unittest
 from test.unified_format import generate_test_classes
 
 # Location of JSON test specifications.
-TEST_PATH = os.path.join(
-    os.path.dirname(os.path.realpath(__file__)), 'transactions', 'unified')
+TEST_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), "transactions", "unified")
 
 # Generate unified tests.
 globals().update(generate_test_classes(TEST_PATH, module=__name__))
