@@ -16,6 +16,8 @@
 
 https://github.com/mongodb/specifications/blob/master/source/unified-test-format/unified-test-format.rst
 """
+from __future__ import annotations
+
 import binascii
 import collections
 import copy
@@ -64,10 +66,11 @@ from bson.codec_options import DEFAULT_CODEC_OPTIONS
 from bson.objectid import ObjectId
 from bson.regex import RE_TYPE, Regex
 from gridfs import GridFSBucket, GridOut
-from pymongo import ASCENDING, MongoClient, _csot
+from pymongo import ASCENDING, CursorType, MongoClient, _csot
 from pymongo.change_stream import ChangeStream
 from pymongo.client_session import ClientSession, TransactionOptions, _TxnState
 from pymongo.collection import Collection
+from pymongo.command_cursor import CommandCursor
 from pymongo.database import Database
 from pymongo.encryption import ClientEncryption
 from pymongo.encryption_options import _HAVE_PYMONGOCRYPT
@@ -99,6 +102,10 @@ from pymongo.monitoring import (
     PoolReadyEvent,
     ServerClosedEvent,
     ServerDescriptionChangedEvent,
+    ServerHeartbeatFailedEvent,
+    ServerHeartbeatListener,
+    ServerHeartbeatStartedEvent,
+    ServerHeartbeatSucceededEvent,
     ServerListener,
     ServerOpeningEvent,
     TopologyEvent,
@@ -106,7 +113,9 @@ from pymongo.monitoring import (
     _ConnectionEvent,
     _PoolEvent,
     _ServerEvent,
+    _ServerHeartbeatEvent,
 )
+from pymongo.operations import SearchIndexModel
 from pymongo.read_concern import ReadConcern
 from pymongo.read_preferences import ReadPreference
 from pymongo.results import BulkWriteResult
@@ -132,14 +141,14 @@ KMS_TLS_OPTS = {
 
 # Build up a placeholder map.
 PLACEHOLDER_MAP = {}
-for (provider_name, provider_data) in [
+for provider_name, provider_data in [
     ("local", {"key": LOCAL_MASTER_KEY}),
     ("aws", AWS_CREDS),
     ("azure", AZURE_CREDS),
     ("gcp", GCP_CREDS),
     ("kmip", KMIP_CREDS),
 ]:
-    for (key, value) in provider_data.items():
+    for key, value in provider_data.items():
         placeholder = f"/clientEncryptionOpts/kmsProviders/{provider_name}/{key}"
         PLACEHOLDER_MAP[placeholder] = value
 
@@ -154,6 +163,7 @@ def with_metaclass(meta, *bases):
 
     Vendored from six: https://github.com/benjaminp/six/blob/master/six.py
     """
+
     # This requires a bit of explanation: the basic idea is to make a dummy
     # metaclass for one level of class instantiation that replaces itself with
     # the actual metaclass.
@@ -285,7 +295,7 @@ class NonLazyCursor:
         self.client = None
 
 
-class EventListenerUtil(CMAPListener, CommandListener, ServerListener):
+class EventListenerUtil(CMAPListener, CommandListener, ServerListener, ServerHeartbeatListener):
     def __init__(
         self, observe_events, ignore_commands, observe_sensitive_commands, store_events, entity_map
     ):
@@ -316,7 +326,11 @@ class EventListenerUtil(CMAPListener, CommandListener, ServerListener):
             return [e for e in self.events if isinstance(e, _CommandEvent)]
         if event_type == "cmap":
             return [e for e in self.events if isinstance(e, (_ConnectionEvent, _PoolEvent))]
-        return [e for e in self.events if isinstance(e, (_ServerEvent, TopologyEvent))]
+        return [
+            e
+            for e in self.events
+            if isinstance(e, (_ServerEvent, TopologyEvent, _ServerHeartbeatEvent))
+        ]
 
     def add_event(self, event):
         event_name = type(event).__name__.lower()
@@ -336,23 +350,32 @@ class EventListenerUtil(CMAPListener, CommandListener, ServerListener):
             self.add_event(event)
 
     def started(self, event):
-        if event.command == {}:
-            # Command is redacted. Observe only if flag is set.
-            if self._observe_sensitive_commands:
+        if isinstance(event, CommandStartedEvent):
+            if event.command == {}:
+                # Command is redacted. Observe only if flag is set.
+                if self._observe_sensitive_commands:
+                    self._command_event(event)
+            else:
                 self._command_event(event)
         else:
-            self._command_event(event)
+            self.add_event(event)
 
     def succeeded(self, event):
-        if event.reply == {}:
-            # Command is redacted. Observe only if flag is set.
-            if self._observe_sensitive_commands:
+        if isinstance(event, CommandSucceededEvent):
+            if event.reply == {}:
+                # Command is redacted. Observe only if flag is set.
+                if self._observe_sensitive_commands:
+                    self._command_event(event)
+            else:
                 self._command_event(event)
         else:
-            self._command_event(event)
+            self.add_event(event)
 
     def failed(self, event):
-        self._command_event(event)
+        if isinstance(event, CommandFailedEvent):
+            self._command_event(event)
+        else:
+            self.add_event(event)
 
     def opened(self, event: ServerOpeningEvent) -> None:
         self.add_event(event)
@@ -744,6 +767,10 @@ class MatchEvaluatorUtil:
             self.test.assertEqual(expectation, actual)
             return None
 
+    def assertHasDatabaseName(self, spec, actual):
+        if "databaseName" in spec:
+            self.test.assertEqual(spec["databaseName"], actual.database_name)
+
     def assertHasServiceId(self, spec, actual):
         if "hasServiceId" in spec:
             if spec.get("hasServiceId"):
@@ -776,27 +803,21 @@ class MatchEvaluatorUtil:
         if name == "commandStartedEvent":
             self.test.assertIsInstance(actual, CommandStartedEvent)
             command = spec.get("command")
-            database_name = spec.get("databaseName")
             if command:
-                if actual.command_name == "update":
-                    # TODO: remove this once PYTHON-1744 is done.
-                    # Add upsert and multi fields back into expectations.
-                    for update in command.get("updates", []):
-                        update.setdefault("upsert", False)
-                        update.setdefault("multi", False)
                 self.match_result(command, actual.command)
-            if database_name:
-                self.test.assertEqual(database_name, actual.database_name)
+            self.assertHasDatabaseName(spec, actual)
             self.assertHasServiceId(spec, actual)
         elif name == "commandSucceededEvent":
             self.test.assertIsInstance(actual, CommandSucceededEvent)
             reply = spec.get("reply")
             if reply:
                 self.match_result(reply, actual.reply)
+            self.assertHasDatabaseName(spec, actual)
             self.assertHasServiceId(spec, actual)
         elif name == "commandFailedEvent":
             self.test.assertIsInstance(actual, CommandFailedEvent)
             self.assertHasServiceId(spec, actual)
+            self.assertHasDatabaseName(spec, actual)
         elif name == "poolCreatedEvent":
             self.test.assertIsInstance(actual, PoolCreatedEvent)
         elif name == "poolReadyEvent":
@@ -832,6 +853,18 @@ class MatchEvaluatorUtil:
                 )
             if "newDescription" in spec:
                 self.match_server_description(actual.new_description, spec["newDescription"])
+        elif name == "serverHeartbeatStartedEvent":
+            self.test.assertIsInstance(actual, ServerHeartbeatStartedEvent)
+            if "awaited" in spec:
+                self.test.assertEqual(actual.awaited, spec["awaited"])
+        elif name == "serverHeartbeatSucceededEvent":
+            self.test.assertIsInstance(actual, ServerHeartbeatSucceededEvent)
+            if "awaited" in spec:
+                self.test.assertEqual(actual.awaited, spec["awaited"])
+        elif name == "serverHeartbeatFailedEvent":
+            self.test.assertIsInstance(actual, ServerHeartbeatFailedEvent)
+            if "awaited" in spec:
+                self.test.assertEqual(actual.awaited, spec["awaited"])
         else:
             raise Exception(f"Unsupported event type {name}")
 
@@ -867,7 +900,7 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
     a class attribute ``TEST_SPEC``.
     """
 
-    SCHEMA_VERSION = Version.from_string("1.12")
+    SCHEMA_VERSION = Version.from_string("1.17")
     RUN_ON_LOAD_BALANCER = True
     RUN_ON_SERVERLESS = True
     TEST_SPEC: Any
@@ -1087,6 +1120,39 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
         kwargs["command"] = ordered_command
         return target.command(**kwargs)
 
+    def _databaseOperation_runCursorCommand(self, target, **kwargs):
+        return list(self._databaseOperation_createCommandCursor(target, **kwargs))
+
+    def _databaseOperation_createCommandCursor(self, target, **kwargs):
+        self.__raise_if_unsupported("createCommandCursor", target, Database)
+        # Ensure the first key is the command name.
+        ordered_command = SON([(kwargs.pop("command_name"), 1)])
+        ordered_command.update(kwargs["command"])
+        kwargs["command"] = ordered_command
+        batch_size = 0
+
+        cursor_type = kwargs.pop("cursor_type", "nonTailable")
+        if cursor_type == CursorType.TAILABLE:
+            ordered_command["tailable"] = True
+        elif cursor_type == CursorType.TAILABLE_AWAIT:
+            ordered_command["tailable"] = True
+            ordered_command["awaitData"] = True
+        elif cursor_type != "nonTailable":
+            self.fail(f"unknown cursorType: {cursor_type}")
+
+        if "maxTimeMS" in kwargs:
+            kwargs["max_await_time_ms"] = kwargs.pop("maxTimeMS")
+
+        if "batch_size" in kwargs:
+            batch_size = kwargs.pop("batch_size")
+
+        cursor = target.cursor_command(**kwargs)
+
+        if batch_size > 0:
+            cursor.batch_size(batch_size)
+
+        return cursor
+
     def _databaseOperation_listCollections(self, target, *args, **kwargs):
         if "batch_size" in kwargs:
             kwargs["cursor"] = {"batchSize": kwargs.pop("batch_size")}
@@ -1133,6 +1199,15 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
     def _collectionOperation_listIndexNames(self, target, *args, **kwargs):
         self.skipTest("PyMongo does not support list_index_names")
 
+    def _collectionOperation_createSearchIndexes(self, target, *args, **kwargs):
+        models = [SearchIndexModel(**i) for i in kwargs["models"]]
+        return target.create_search_indexes(models)
+
+    def _collectionOperation_listSearchIndexes(self, target, *args, **kwargs):
+        name = kwargs.get("name")
+        agg_kwargs = kwargs.get("aggregation_options", dict())
+        return list(target.list_search_indexes(name, **agg_kwargs))
+
     def _sessionOperation_withTransaction(self, target, *args, **kwargs):
         if client_context.storage_engine == "mmapv1":
             self.skipTest("MMAPv1 does not support document-level locking")
@@ -1150,7 +1225,9 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
         return next(target)
 
     def _cursor_iterateUntilDocumentOrError(self, target, *args, **kwargs):
-        self.__raise_if_unsupported("iterateUntilDocumentOrError", target, NonLazyCursor)
+        self.__raise_if_unsupported(
+            "iterateUntilDocumentOrError", target, NonLazyCursor, CommandCursor
+        )
         while target.alive:
             try:
                 return next(target)
@@ -1159,7 +1236,7 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
         return None
 
     def _cursor_close(self, target, *args, **kwargs):
-        self.__raise_if_unsupported("close", target, NonLazyCursor)
+        self.__raise_if_unsupported("close", target, NonLazyCursor, CommandCursor)
         return target.close()
 
     def _clientEncryptionOperation_createDataKey(self, target, *args, **kwargs):
@@ -1250,7 +1327,7 @@ class UnifiedSpecTestMixinV1(IntegrationTest):
                         doc.setdefault("metadata", {})["contentType"] = doc.pop("contentType")
         elif isinstance(target, ChangeStream):
             method_name = f"_changeStreamOperation_{opname}"
-        elif isinstance(target, NonLazyCursor):
+        elif isinstance(target, (NonLazyCursor, CommandCursor)):
             method_name = f"_cursor_{opname}"
         elif isinstance(target, ClientSession):
             method_name = f"_sessionOperation_{opname}"
